package request

import (
	"gorm.io/gorm"
	pb "sghgogs.com/micro/auth-service/proto"
	"time"
)

// Team 直接将用户添加到团队的 Members 中
// db.Model(&team).Update("Members", gorm.Expr("ARRAY_APPEND(members, ?)", userID))
// 假设 teamID 为团队的 ID
// var team Team
// if err := db.Preload("Members").First(&team, teamID).Error; err != nil {
// // 处理团队不存在的情况
// }
type Team struct {
	ID               int64         `gorm:"primary_key;not_null;auto_increment;" json:"id"`
	Name             string        `json:"name"`        // 团队名称
	Description      string        `json:"description"` // 团队描述
	CreatedBy        string        `json:"created_by"`  // 创建团队的用户
	UpdatedBy        string        `json:"updated_by"`  // 更新团队的用户
	CreatedAt        time.Time     `json:"created_at"`  // 团队创建时间
	Avatar           string        `json:"avatar"`      // 团队头像
	UpdatedAt        *time.Time    `json:"updated_at"`
	Website          string        `json:"website"`                             // 团队网站
	MaxMembers       int32         `json:"max_members"`                         // 团队最大成员数
	Status           pb.StatusEnum `json:"status" gorm:"unique_index;not_null"` // 可以是 "enabled", "disabled", "deleted" 等
	Credential       string        `json:"credential"`
	RegistrationDate gorm.DeletedAt
}
