package repository

import (
	"fmt"
	req "sghgogs.com/micro/auth-service/domain/model/request"
	pb "sghgogs.com/micro/auth-service/proto"
	"sghgogs.com/micro/auth-service/utils/authutil"
	"time"
)

func (u *Repository) GetTeamList(query *pb.GetTeamListRequest) ([]req.Team, int64, error) {
	teams := make([]req.Team, 0)
	// u.db.Model(&req.Team{}).Where()
	var totalCount int64
	tx := u.db.Model(&req.Team{}).Order("id desc").Select("id, name, description, created_by, created_at, updated_at, website, max_members, status, avatar")
	if query.Keyword != "" {
		tx.Where("name = ? ", query.Keyword)
	}
	if query.Status > 0 {
		tx.Where("status = ?", query.Status)
	}
	tx.Count(&totalCount)
	// users := make([]req.AdminUser, 0)
	return teams, totalCount, tx.Limit(int(query.PageSize)).Offset(int((query.Page - 1) * query.PageSize)).Find(&teams).Error
}

func (u *Repository) GetAllTeams() ([]req.Team, error) {
	teams := make([]req.Team, 0)
	return teams, u.db.Model(&req.Team{}).Where("status = ?", pb.StatusEnum_ENABLED).Select("name, description").
		Order("id desc").Find(&teams).Error
}

func (u *Repository) GetTeam(query *pb.GetTeamRequest) (req.Team, error) {
	var team req.Team
	return team, u.db.Model(&req.Team{}).Where("id = ? OR name = ?", query.TeamId, query.Keyword).First(&team).Error
}

func (u *Repository) CreateTeam(team *req.Team) error {
	// 开始事务
	tx := u.db.Begin()
	// 错误处理
	defer func() {
		if r := recover(); r != nil {
			tx.Rollback()
		}
	}()
	if err := tx.Create(&team).Error; err != nil {
		tx.Rollback()
		return err
	}
	expiry := time.Second * time.Duration(720*3600)
	md := map[string]string{}
	md["name"] = team.Name
	md["team_id"] = fmt.Sprintf("%d", team.ID)
	md["expiry"] = fmt.Sprintf("%d", time.Now().Add(expiry).Unix())
	generate, err := authutil.JWTAuthService.GenerateTeamToken(team.ID, md)
	if err != nil {
		tx.Rollback()
		return err
	}
	token, err := authutil.JWTAuthService.Token(team.ID, generate.Secret, expiry)
	if err != nil {
		tx.Rollback()
		return err
	}
	if err = tx.Model(&req.Team{}).Where("id = ?", team.ID).Updates(map[string]interface{}{"credential": token.AccessToken}).Error; err != nil {
		tx.Rollback()
		return err
	}
	return tx.Commit().Error
}

func (u *Repository) ToggleTeam(query *pb.ToggleTeamRequest) error {
	return u.db.Model(&req.Team{}).Where("id = ? ", query.TeamId).Updates(map[string]interface{}{
		"status":     query.Status,
		"updated_at": time.Now(),
		"updated_by": query.UpdatedBy,
	}).Error
}

func (u *Repository) UpdateTeam(query *pb.UpdateTeamRequest) error {
	return u.db.Model(&req.Team{}).Where("id = ?", query.TeamId).Updates(map[string]interface{}{
		"name":        query.Name,
		"description": query.Description,
		"website":     query.Website,
		"max_members": query.MaxMembers,
		"updated_at":  time.Now(),
		"updated_by":  query.UpdatedBy,
	}).Error
}

func (u *Repository) DeleteTeam(query *pb.DeleteTeamRequest) error {
	return u.db.Model(&req.Team{}).Where("id = ?", query.TeamId).Delete(&req.Team{ID: query.TeamId}).Error
}
