package service

import (
	"context"
	req "sghgogs.com/micro/auth-service/domain/model/request"
	pb "sghgogs.com/micro/auth-service/proto"
	"sghgogs.com/micro/common"
	"sghgogs.com/micro/common/errorcode"
	"time"
)

func (s *Service) GetTeamList(query *pb.GetTeamListRequest) ([]*pb.Team, int64, error) {
	teams := make([]*pb.Team, 0)
	list, i, err := s.Repository.GetTeamList(query)
	if err != nil {
		return teams, 0, errorcode.New(s.Namespace, err.Error(), 500)
	}
	for _, item := range list {
		teams = append(teams, s.getTeamRes(item))
	}
	return teams, i, nil
}

func (s *Service) GetTeam(query *pb.GetTeamRequest) (*pb.Team, error) {
	team, err := s.Repository.GetTeam(query)
	if err != nil {
		return &pb.Team{}, errorcode.New(s.Namespace, err.Error(), 500)
	}
	return s.getTeamRes(team), nil
}

func (s *Service) getTeamRes(team req.Team) *pb.Team {
	var res pb.Team
	common.SwapTo(team, &res)
	res.CreatedAt = ConvertTimeToInt64(team.CreatedAt)
	if team.UpdatedAt != nil {
		res.UpdatedAt = ConvertTimeToInt64(*team.UpdatedAt)
	}
	return &res
}

func (s *Service) GetAllTeams() ([]*pb.Team, error) {
	teams := make([]*pb.Team, 0)
	list, err := s.Repository.GetAllTeams()
	if err != nil {
		return teams, errorcode.New(s.Namespace, err.Error(), 500)
	}
	for _, item := range list {
		teams = append(teams, s.getTeamRes(item))
	}
	return teams, nil
}

func (s *Service) CreateTeam(ctx context.Context, team *pb.Team) error {
	_, by, _, _ := ParseMetadata(ctx)
	if err := s.Repository.CreateTeam(&req.Team{
		Name:        team.Name,
		Description: team.Description,
		CreatedBy:   by,
		CreatedAt:   time.Now(),
		UpdatedAt:   nil,
		Website:     team.Website,
		Avatar:      team.Avatar,
		MaxMembers:  team.MaxMembers,
		Status:      pb.StatusEnum_ENABLED,
	}); err != nil {
		return errorcode.New(s.Namespace, err.Error(), 500)
	}
	return nil
}

func (s *Service) ToggleTeam(ctx context.Context, query *pb.ToggleTeamRequest) error {
	_, by, _, _ := ParseMetadata(ctx)
	query.UpdatedBy = by
	if err := s.Repository.ToggleTeam(query); err != nil {
		return errorcode.New(s.Namespace, err.Error(), 500)
	}
	return nil
}

func (s *Service) UpdateTeam(ctx context.Context, query *pb.UpdateTeamRequest) error {
	_, by, _, _ := ParseMetadata(ctx)
	query.UpdatedBy = by
	if err := s.Repository.UpdateTeam(query); err != nil {
		return errorcode.New(s.Namespace, err.Error(), 500)
	}
	return nil
}

func (s *Service) DeleteTeam(ctx context.Context, query *pb.DeleteTeamRequest) error {
	_, by, _, _ := ParseMetadata(ctx)
	query.UpdatedBy = by
	if err := s.Repository.DeleteTeam(query); err != nil {
		return errorcode.New(s.Namespace, err.Error(), 500)
	}
	return nil
}
