package team

import (
	"context"
	"fmt"
	"github.com/redis/go-redis/v9"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	"sghgogs.com/micro/auth-service/domain/repository"
	"sghgogs.com/micro/auth-service/domain/service"
	pb "sghgogs.com/micro/auth-service/proto"
	"sghgogs.com/micro/auth-service/utils/authutil"
	"strconv"
	"testing"
	"time"
)

func TestTeam(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "sghblog")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	t.Run("初始化", func(t *testing.T) {
		repo.InitTable()
	})
	t.Run("初始化", func(t *testing.T) {
		// authutil.NewJWTAuth(redis.NewClient(&redis.Options{
		// 	Addr:     "localhost:6379", // Redis 服务器地址
		// 	Password: "xugang131500",   // Redis 密码，如果有的话
		// 	DB:       0,                // 默认数据库
		// }), "authorizationservice", true)
	})
	newService := service.NewService(repo, "authorizationservice")
	t.Run("创建", func(t *testing.T) {
		authutil.NewJWTAuth(redis.NewClient(&redis.Options{
			Addr:     "localhost:6379", // Redis 服务器地址
			Password: "xugang131500",   // Redis 密码，如果有的话
			DB:       0,                // 默认数据库
		}), "authorizationservice", true)
		err2 := newService.CreateTeam(context.Background(), &pb.Team{
			Name:        "shoppingservice_wanke",
			Description: "万科",
			CreatedBy:   "system",
			MaxMembers:  10,
		})
		fmt.Println(err2)
		// fmt.Println(err2)
	})
	t.Run("获取列表", func(t *testing.T) {
		list, i, err2 := newService.GetTeamList(&pb.GetTeamListRequest{
			Page:     1,
			PageSize: 10,
		})
		fmt.Println(list)
		fmt.Println(i)
		fmt.Println(err2)
	})
	t.Run("获取详情", func(t *testing.T) {
		authutil.NewJWTAuth(redis.NewClient(&redis.Options{
			Addr:     "localhost:6379", // Redis 服务器地址
			Password: "xugang131500",   // Redis 密码，如果有的话
			DB:       0,                // 默认数据库
		}), "authorizationservice", true)
		team, err2 := newService.GetTeam(&pb.GetTeamRequest{Keyword: "shoppingservice_wanke"})
		fmt.Println(team)
		inspect, err2 := authutil.JWTAuthService.Inspect(team.Credential)
		if value, ok := inspect.Metadata["expiry"]; ok {
			expiry, _ := strconv.ParseInt(value, 10, 64)
			fmt.Println("expiry", expiry-time.Now().Unix())
		}
		fmt.Println(inspect)
		fmt.Println(err2)
	})
	// service.NewService(repo)
}
